@@ -1,9 +1,9 @@
+from .diffjpeg import DiffJPEG
 from .file_client import FileClient
+from .img_process_util import USMSharp, usm_sharp
 from .img_util import crop_border, imfrombytes, img2tensor, imwrite, tensor2img
-from .logger import (MessageLogger, get_env_info, get_root_logger,
-                     init_tb_logger, init_wandb_logger)
-from .misc import (check_resume, get_time_str, make_exp_dirs, mkdir_and_rename,
-                   scandir, set_random_seed, sizeof_fmt)
+from .logger import MessageLogger, get_env_info, get_root_logger, init_tb_logger, init_wandb_logger
+from .misc import check_resume, get_time_str, make_exp_dirs, mkdir_and_rename, scandir, set_random_seed, sizeof_fmt
 
 __all__ = [
     # file_client.py
@@ -27,5 +27,10 @@ __all__ = [
     'make_exp_dirs',
     'scandir',
     'check_resume',
-    'sizeof_fmt'
+    'sizeof_fmt',
+    # diffjpeg
+    'DiffJPEG',
+    # img_process_util
+    'USMSharp',
+    'usm_sharp'
 ]
